Kill global close_filters().
[paraslash.git] / client.h
index a4d2fe63f473aeb96432dcee1d9b362b77f95f45..98dc32db5fdd547db412836e2f0925436064c3e7 100644 (file)
--- a/client.h
+++ b/client.h
@@ -1,95 +1,70 @@
 /*
- * Copyright (C) 1997-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2009 Andre Noll <maan@systemlinux.org>
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
-/** \file client.h common client functions and exported symbols from client_common.c */
+/** \file client.h Common client functions and exported symbols from client_common.c. */
 
 #include <openssl/rc4.h>
 
-/**
- * the different states of a connection from the view of the client
- */
+/** The different states of a connection from the view of the client. */
 enum {
-       /** tcp connection is established */
+       /** TCP connection is established. */
        CL_CONNECTED,
-       /** server sends the welcome message */
+       /** Server sends the welcome message. */
        CL_RECEIVED_WELCOME,
-       /** client sends the authentification request */
+       /** Client sends the authentification request. */
        CL_SENT_AUTH,
-       /** server sends a challenge */
+       /** Server sends a challenge. */
        CL_RECEIVED_CHALLENGE,
-       /** clientd solves the challenge and sends the result */
+       /** Client solves the challenge and sends the result. */
        CL_SENT_CH_RESPONSE,
-       /** server accepts this authentication */
+       /** Server accepts this authentication. */
        CL_RECEIVED_PROCEED,
-       /** client sends the command */
+       /** Client sends the command. */
        CL_SENT_COMMAND,
-       /** server expects data */
+       /** Server expects data. */
        CL_SENDING,
-       /** client expects data */
+       /** Client expects data. */
        CL_RECEIVING,
 };
 
-/** size of the receiving buffer */
+/** The size of the receiving buffer. */
 #define CLIENT_BUFSIZE 8192
 
-/**
- * data specific to a client task
- */
-struct private_client_data {
-       /** the state of the connection */
+/** Data specific to a client task. */
+struct client_task {
+       /** The state of the connection. */
        int status;
-       /** the file descriptor */
-       int fd;
-       /** the configuration (including the command) */
+       /** The file descriptor and the rc4 keys. */
+       struct rc4_context rc4c;
+       /** The configuration (including the command). */
        struct client_args_info conf;
-       /** the config file for client options */
+       /** The config file for client options. */
        char *config_file;
-       /** the RSA private key */
+       /** The RSA private key. */
        char *key_file;
-       /** paraslash user name */
+       /** Paraslash user name. */
        char *user;
-       /** session key for receiving data */
-       RC4_KEY rc4_recv_key;
-       /** session key for sending data */
-       RC4_KEY rc4_send_key;
-       /** the client task structure */
+       /** The client task structure. */
        struct task task;
-       /** non-zero if task is unregistered */
-       int eof;
-       /** the buffer used for handshake and receiving */
-       char buf[CLIENT_BUFSIZE];
-       /** number of bytes loaded in \p buf */
+       /** The buffer used for handshake and receiving. */
+       char *buf;
+       /** Number of bytes loaded in \a buf. */
        size_t loaded;
-       /** non-zero if the pre_select hook added \p fd to the read fd set */
+       /** Non-zero if the pre_select hook added \a fd to the read fd set. */
        int check_r;
-       /** non-zero if the pre_select hook added \p fd to the write fd set */
+       /** Non-zero if the pre_select hook added \a fd to the write fd set. */
        int check_w;
-       /** the decrypted challenge */
-       long unsigned challenge_nr;
-       /** pointer to the data to be sent to para_server */
+       /** Pointer to the data to be sent to para_server. */
        char *inbuf;
-       /** number of bytes loaded in \p inbuf */
+       /** Number of bytes loaded in \a inbuf. */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
-void client_close(struct private_client_data *pcd);
-int client_open(int argc, char *argv[], struct private_client_data **pcd_ptr);
-void client_pre_select(struct sched *s, struct task *t);
-void client_post_select(struct sched *s, struct task *t);
+void client_close(struct client_task *ct);
+int client_open(int argc, char *argv[], struct client_task **ct,
+               int *loglevel);